import pandas as pd
import matplotlib.pyplot as plt

def calculate_rsi(prices, period=14):
    # Convert prices to a Pandas Series
    prices = pd.Series(prices)
    delta = prices.diff(1)
    gain = (delta.where(delta > 0, 0)).rolling(window=period).mean()
    loss = (-delta.where(delta < 0, 0)).rolling(window=period).mean()

    rs = gain / loss
    rsi = 100 - (100 / (1 + rs))
    return rsi

def plot_rsi(prices):
    rsi = calculate_rsi(prices)
    plt.figure(figsize=(10, 6))
    plt.plot(rsi, label="RSI")
    plt.axhline(30, color='red', linestyle='--', label='Oversold (30)')
    plt.axhline(70, color='green', linestyle='--', label='Overbought (70)')
    plt.legend()
    plt.title("RSI Plot")
    plt.show()

    if rsi.iloc[-1] < 30:
        return "BUY"
    elif rsi.iloc[-1] > 70:
        return "SELL"
    else:
        return "HOLD"



import numpy as np
from scipy import stats

def calculate_statistics(stock_prices, market_prices):
    # Calculate the mean, median, mode, standard deviation, variance, covariance, and correlation
    mean = np.mean(stock_prices)
    median = np.median(stock_prices)
    
    # Corrected mode calculation
    mode_result = stats.mode(stock_prices)
    mode = mode_result.mode[0]  # Access the mode value correctly
    
    std_dev = np.std(stock_prices)
    variance = np.var(stock_prices)
    
    # Calculate covariance and correlation between stock and market prices
    covariance = np.cov(stock_prices, market_prices)[0][1]
    correlation = np.corrcoef(stock_prices, market_prices)[0][1]
    
    # Prepare insights
    insights = {
        "Mean": mean,
        "Median": median,
        "Mode": mode,
        "Standard Deviation": std_dev,
        "Variance": variance,
        "Covariance": covariance,
        "Correlation Coefficient": correlation
    }
    
    return insights


import pandas as pd
import matplotlib.pyplot as plt

def calculate_macd(prices, short_period=12, long_period=26, signal_period=9):
    prices = pd.Series(prices)
    short_ema = prices.ewm(span=short_period, adjust=False).mean()
    long_ema = prices.ewm(span=long_period, adjust=False).mean()
    macd = short_ema - long_ema
    signal = macd.ewm(span=signal_period, adjust=False).mean()
    return macd, signal

def plot_macd(prices):
    macd, signal = calculate_macd(prices)
    plt.figure(figsize=(10, 6))
    plt.plot(macd, label="MACD", color='blue')
    plt.plot(signal, label="Signal Line", color='red')
    plt.legend()
    plt.title("MACD Plot")
    plt.show()

    if macd.iloc[-1] > signal.iloc[-1]:
        return "BUY"
    elif macd.iloc[-1] < signal.iloc[-1]:
        return "SELL"
    else:
        return "HOLD"



from setuptools import setup, find_packages

setup(
    name='ATACS',
    version='0.1.3',
    author='Chirag Bhatia',
    author_email='chiragbhatia2002@yahoo.com',
    description='A Python package for financial analysis including RSI, MACD, and statistical insights.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=[
        'pandas',
        'matplotlib',
        'scipy',
        'numpy'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
